Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(66)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/text/editor/IJavaAnnotation.java

Issue 10816034: Basic 'Quick Fix' support and one fix as example/test (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/text/editor/IJavaAnnotation.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/text/editor/IJavaAnnotation.java b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/text/editor/IJavaAnnotation.java
index 52ace8bb0281494dd992f3754db0ca1d723551a0..d7e4aa3d33a0b76dfb1ad3dbce0e121d87a78df6 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/text/editor/IJavaAnnotation.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui/src/com/google/dart/tools/ui/internal/text/editor/IJavaAnnotation.java
@@ -13,6 +13,7 @@
*/
package com.google.dart.tools.ui.internal.text.editor;
+import com.google.dart.compiler.ErrorCode;
import com.google.dart.tools.core.model.CompilationUnit;
import java.util.Iterator;
@@ -47,11 +48,9 @@ public interface IJavaAnnotation {
CompilationUnit getCompilationUnit();
/**
* Returns the problem id or <code>-1</code> if no problem id can be evaluated.
*
* @return returns the problem id or <code>-1</code>
*/
- int getId();
+ ErrorCode getId();
/**
* Returns the marker type associated to this problem or <code>null<code> if no marker type
@@ -47,11 +48,9 @@ public interface IJavaAnnotation {
CompilationUnit getCompilationUnit();
/**
- * Returns the problem id or <code>-1</code> if no problem id can be evaluated.
- *
- * @return returns the problem id or <code>-1</code>
+ * @return the problem {@link ErrorCode} or <code>null</code> if problem code can't be evaluated.
*/

Powered by Google App Engine
This is Rietveld 408576698